@@ -42,6 +42,7 @@ class RESTInterface:
         self._api_key_id = config["api_key_id"]
         self._api_key_secret = config["api_key_secret"]
         self._pretty = config["pretty"]
+        self._dry_run = config["dry_run"]
 
         auth_header_value = "Bearer " + base64.b64encode(
             bytes(f"{self._api_key_id}:{self._api_key_secret}", "utf-8")
@@ -81,6 +82,8 @@ class RESTInterface:
             raise Exception(response_data)
 
     def _get_resource(self, resource_path):
+        if self._dry_run:
+            return {}
         r = requests.get(f"{self._api_url}/{resource_path}", headers=self._headers)
         try:
             response_data = r.json()
@@ -92,6 +95,8 @@ class RESTInterface:
             raise Exception(response_data)
 
     def _create_resource(self, resource_path, data):
+        if self._dry_run:
+            return {}
         r = requests.post(
             f"{self._api_url}/{resource_path}",
             data=json.dumps(data),
@@ -100,6 +105,8 @@ class RESTInterface:
         return self._handle_response_data(r)
 
     def _update_resource(self, resource_path, data):
+        if self._dry_run:
+            return {}
         r = requests.patch(
             f"{self._api_url}/{resource_path}",
             data=json.dumps(data),
@@ -108,5 +115,7 @@ class RESTInterface:
         return self._handle_response_data(r)
 
     def _delete_resource(self, resource_path):
+        if self._dry_run:
+            return
         r = requests.delete(f"{self._api_url}/{resource_path}", headers=self._headers)
         return self._handle_response_data(r)
